@@ -366,8 +366,10 @@ class Database(object):
                    from all_tab_partitions{} \
                    where table_owner = '{}' and table_name = '{}'"
             sql = sql.format(dblink_txt, owner.upper(), table.upper())
-
-        return self.get_one(sql)
+        partitions = {}
+        for partition, rows in self.get_all(sql):
+            partitions[partition] = rows
+        return partitions
 
     def get_table_columns(self, table, owner=None, dblink=None):
         """Retorna una llista amb les columnes de la taula."""
